@@ -11,10 +11,14 @@ use std::env;
 use std::io::{IsTerminal, stdout};
 use std::path::PathBuf;
 use std::process::ExitCode;
+#[cfg(feature = "update-notifications")]
+use std::time::Duration;
 
 use nu_ansi_term::Color::*;
 use rustyline::error::ReadlineError;
 use rustyline::DefaultEditor;
+#[cfg(feature = "update-notifications")]
+use update_informer::{registry, Check};
 
 mod config;
 mod expr;
@@ -48,7 +52,7 @@ fn main() -> ExitCode {
 
     let env_var_value = std::env::var("NO_COLOR").ok().unwrap_or(String::new());
     let env_no_color = str_to_bool(&env_var_value).unwrap_or(false);
-    let mut no_color = env_no_color || (config.no_color.is_some() && config.no_color.unwrap());
+    let mut no_color = env_no_color || config.no_color.unwrap_or(false);
 
     #[cfg(windows)]
     {
@@ -129,6 +133,9 @@ fn main() -> ExitCode {
                 loop {
                     let readline = rl.readline("query> ");
                     match readline {
+                        Ok(cmd) if cmd.to_ascii_lowercase().trim() == "quit" || cmd.to_ascii_lowercase().trim() == "exit" => {
+                            break
+                        },
                         Ok(query) => {
                             let _ = rl.add_history_entry(query.as_str());
                             exec_search(query, &mut config, no_color);
@@ -161,6 +168,17 @@ fn main() -> ExitCode {
 
     config.save();
 
+    #[cfg(feature = "update-notifications")]
+    if config.check_for_updates.unwrap_or(false) && stdout().is_terminal() {
+        let name = env!("CARGO_PKG_NAME");
+        let version = env!("CARGO_PKG_VERSION");
+        let informer = update_informer::new(registry::Crates, name, version).interval(Duration::from_secs(60 * 60 * 24));
+
+        if let Some(version) = informer.check_version().ok().flatten()  {
+            println!("\nNew version is available! : {}", version);
+        }
+    }
+
     if let Some(exit_value) = exit_value {
         return ExitCode::from(exit_value);
     }
@@ -412,6 +430,7 @@ Functions:
         CONCAT                      Returns concatenated string of expression values
         CONCAT_WS                   Returns concatenated string of expression values with specified delimiter
         FORMAT_SIZE                 Returns formatted size of a file
+        FORMAT_TIME | PRETTY_TIME   Returns human-readable durations of time in seconds
         RANDOM | RAND               Returns random integer (from zero to max int, from zero to arg, or from arg1 to arg2)
 
 Expressions:
@@ -428,6 +447,7 @@ Expressions:
         !=~ | !~= | notrx           Used to check if the column value doesn't match the regex pattern
         like                        Used to check if the column value matches the pattern which follows SQL conventions
         notlike                     Used to check if the column value doesn't match the pattern which follows SQL conventions
+        between                     Used to check if the column value lies between two values inclusive
     Logical Operators:
         and                         Used as an AND operator for two conditions made with the above operators
         or                          Used as an OR operator for two conditions made with the above operators
